==> huaweicloudsdkmeeting-3.0.54-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/query_corp_result_dto.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class QueryCorpResultDTO:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'basic_info': 'QueryCorpBasicResultDTO',
        'admin_info': 'QueryAdminResultDTO',
        'res_info': 'QueryCorpResResultDTO',
        'group_dto': 'OrgGroupDTO',
        'id': 'str'
    }

    attribute_map = {
        'basic_info': 'basicInfo',
        'admin_info': 'adminInfo',
        'res_info': 'resInfo',
        'group_dto': 'groupDTO',
        'id': 'id'
    }

    def __init__(self, basic_info=None, admin_info=None, res_info=None, group_dto=None, id=None):
        """QueryCorpResultDTO - a model defined in huaweicloud sdk"""
        
        

        self._basic_info = None
        self._admin_info = None
        self._res_info = None
        self._group_dto = None
        self._id = None
        self.discriminator = None

        if basic_info is not None:
            self.basic_info = basic_info
        if admin_info is not None:
            self.admin_info = admin_info
        if res_info is not None:
            self.res_info = res_info
        if group_dto is not None:
            self.group_dto = group_dto
        if id is not None:
            self.id = id

    @property
    def basic_info(self):
        """Gets the basic_info of this QueryCorpResultDTO.


        :return: The basic_info of this QueryCorpResultDTO.
        :rtype: QueryCorpBasicResultDTO
        """
        return self._basic_info

    @basic_info.setter
    def basic_info(self, basic_info):
        """Sets the basic_info of this QueryCorpResultDTO.


        :param basic_info: The basic_info of this QueryCorpResultDTO.
        :type: QueryCorpBasicResultDTO
        """
        self._basic_info = basic_info

    @property
    def admin_info(self):
        """Gets the admin_info of this QueryCorpResultDTO.


        :return: The admin_info of this QueryCorpResultDTO.
        :rtype: QueryAdminResultDTO
        """
        return self._admin_info

    @admin_info.setter
    def admin_info(self, admin_info):
        """Sets the admin_info of this QueryCorpResultDTO.


        :param admin_info: The admin_info of this QueryCorpResultDTO.
        :type: QueryAdminResultDTO
        """
        self._admin_info = admin_info

    @property
    def res_info(self):
        """Gets the res_info of this QueryCorpResultDTO.


        :return: The res_info of this QueryCorpResultDTO.
        :rtype: QueryCorpResResultDTO
        """
        return self._res_info

    @res_info.setter
    def res_info(self, res_info):
        """Sets the res_info of this QueryCorpResultDTO.


        :param res_info: The res_info of this QueryCorpResultDTO.
        :type: QueryCorpResResultDTO
        """
        self._res_info = res_info

    @property
    def group_dto(self):
        """Gets the group_dto of this QueryCorpResultDTO.


        :return: The group_dto of this QueryCorpResultDTO.
        :rtype: OrgGroupDTO
        """
        return self._group_dto

    @group_dto.setter
    def group_dto(self, group_dto):
        """Sets the group_dto of this QueryCorpResultDTO.


        :param group_dto: The group_dto of this QueryCorpResultDTO.
        :type: OrgGroupDTO
        """
        self._group_dto = group_dto

    @property
    def id(self):
        """Gets the id of this QueryCorpResultDTO.

        企业id

        :return: The id of this QueryCorpResultDTO.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryCorpResultDTO.

        企业id

        :param id: The id of this QueryCorpResultDTO.
        :type: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryCorpResultDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmeeting-3.0.78-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/query_corp_result_dto.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class QueryCorpResultDTO:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'basic_info': 'QueryCorpBasicResultDTO',
        'admin_info': 'QueryAdminResultDTO',
        'res_info': 'QueryCorpResResultDTO',
        'group_dto': 'OrgGroupDTO',
        'id': 'str'
    }

    attribute_map = {
        'basic_info': 'basicInfo',
        'admin_info': 'adminInfo',
        'res_info': 'resInfo',
        'group_dto': 'groupDTO',
        'id': 'id'
    }

    def __init__(self, basic_info=None, admin_info=None, res_info=None, group_dto=None, id=None):
        """QueryCorpResultDTO - a model defined in huaweicloud sdk"""
        
        

        self._basic_info = None
        self._admin_info = None
        self._res_info = None
        self._group_dto = None
        self._id = None
        self.discriminator = None

        if basic_info is not None:
            self.basic_info = basic_info
        if admin_info is not None:
            self.admin_info = admin_info
        if res_info is not None:
            self.res_info = res_info
        if group_dto is not None:
            self.group_dto = group_dto
        if id is not None:
            self.id = id

    @property
    def basic_info(self):
        """Gets the basic_info of this QueryCorpResultDTO.


        :return: The basic_info of this QueryCorpResultDTO.
        :rtype: QueryCorpBasicResultDTO
        """
        return self._basic_info

    @basic_info.setter
    def basic_info(self, basic_info):
        """Sets the basic_info of this QueryCorpResultDTO.


        :param basic_info: The basic_info of this QueryCorpResultDTO.
        :type: QueryCorpBasicResultDTO
        """
        self._basic_info = basic_info

    @property
    def admin_info(self):
        """Gets the admin_info of this QueryCorpResultDTO.


        :return: The admin_info of this QueryCorpResultDTO.
        :rtype: QueryAdminResultDTO
        """
        return self._admin_info

    @admin_info.setter
    def admin_info(self, admin_info):
        """Sets the admin_info of this QueryCorpResultDTO.


        :param admin_info: The admin_info of this QueryCorpResultDTO.
        :type: QueryAdminResultDTO
        """
        self._admin_info = admin_info

    @property
    def res_info(self):
        """Gets the res_info of this QueryCorpResultDTO.


        :return: The res_info of this QueryCorpResultDTO.
        :rtype: QueryCorpResResultDTO
        """
        return self._res_info

    @res_info.setter
    def res_info(self, res_info):
        """Sets the res_info of this QueryCorpResultDTO.


        :param res_info: The res_info of this QueryCorpResultDTO.
        :type: QueryCorpResResultDTO
        """
        self._res_info = res_info

    @property
    def group_dto(self):
        """Gets the group_dto of this QueryCorpResultDTO.


        :return: The group_dto of this QueryCorpResultDTO.
        :rtype: OrgGroupDTO
        """
        return self._group_dto

    @group_dto.setter
    def group_dto(self, group_dto):
        """Sets the group_dto of this QueryCorpResultDTO.


        :param group_dto: The group_dto of this QueryCorpResultDTO.
        :type: OrgGroupDTO
        """
        self._group_dto = group_dto

    @property
    def id(self):
        """Gets the id of this QueryCorpResultDTO.

        企业id

        :return: The id of this QueryCorpResultDTO.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryCorpResultDTO.

        企业id

        :param id: The id of this QueryCorpResultDTO.
        :type: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryCorpResultDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
